/*
 *  CELLS       An Implementation of the WireWorld cellular automata
 *              as described in Scientific American, Jan 1990.
 *
 *              Copyright 1990 by Davide P. Cervone.
 *  You may use this code, provided this copyright notice is kept intact.
 *  See the CELLS.HELP file for complete information on distribution conditions.
 */

/*
 *  File:  cImageData.c         Data for the arrows and zoom gadgets,
 *                              the check mark, and the picture of the author.
 */


#include <exec/types.h>


#define IMAGEWIDTH       10
#define IMAGEHEIGHT      10
#define IMAGEDEPTH       2
#define WORDSPERROW      1

USHORT UpArrowData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFC0,
    0x8C40,
    0x9240,
    0xA140,
    0xC0C0,
    0x9240,
    0x9240,
    0x9240,
    0x8E40,
    0xFFC0,
  },
  {
    0x0000,
    0x7BC0,
    0x71C0,
    0x60C0,
    0x4040,
    0x71C0,
    0x71C0,
    0x71C0,
    0x71C0,
    0xFFC0,
  },
};

USHORT DownArrowData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFC0,
    0x9E40,
    0x9240,
    0x9240,
    0x9240,
    0xF0C0,
    0xA140,
    0x9240,
    0x8C40,
    0xFFC0,
  },
  {
    0x0000,
    0x7FC0,
    0x71C0,
    0x71C0,
    0x71C0,
    0x7040,
    0x60C0,
    0x71C0,
    0x7BC0,
    0xFFC0,
  },
};

USHORT LeftArrowData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFC0,
    0x8840,
    0x9040,
    0xA740,
    0xC0C0,
    0xC0C0,
    0xA7C0,
    0x9040,
    0x8840,
    0xFFC0,
  },
  {
    0x0040,
    0x7FC0,
    0x77C0,
    0x67C0,
    0x4040,
    0x0040,
    0x4040,
    0x67C0,
    0x77C0,
    0x7FC0,
  },
};

USHORT RightArrowData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFC0,
    0x8440,
    0x8640,
    0xFD40,
    0xC0C0,
    0xC0C0,
    0xB940,
    0x8240,
    0x8440,
    0xFFC0,
  },
  {
    0x0040,
    0x7FC0,
    0x7FC0,
    0x7DC0,
    0x40C0,
    0x4040,
    0x40C0,
    0x79C0,
    0x7BC0,
    0x7FC0,
  },
};

USHORT ZoomData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFC0,
    0xC0C0,
    0xAD40,
    0x9E40,
    0xBF40,
    0xBF40,
    0x9E40,
    0xAD40,
    0xC0C0,
    0xFFC0,
  },
  {
    0x0000,
    0x3FC0,
    0x57C0,
    0x67C0,
    0x47C0,
    0x78C0,
    0x79C0,
    0x7AC0,
    0x7F40,
    0x7FC0,
  },
};

USHORT ShrinkData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFC0,
    0x8040,
    0xBF40,
    0xB340,
    0xAD40,
    0xAD40,
    0xB340,
    0xBF40,
    0x8040,
    0xFFC0,
  },
  {
    0x0000,
    0x7FC0,
    0x47C0,
    0x4FC0,
    0x57C0,
    0x7AC0,
    0x7CC0,
    0x78C0,
    0x7FC0,
    0x7FC0,
  },
};

#undef  IMAGEWIDTH
#undef  IMAGEHEIGHT
#define IMAGEWIDTH       8
#define IMAGEHEIGHT      8

USHORT CheckData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0x0300,
    0x0400,
    0x0900,
    0xD200,
    0x2400,
    0x8800,
    0x5000,
    0x2000,
  },
  {
    0xFF00,
    0xFC00,
    0xF800,
    0xF100,
    0x2300,
    0x0700,
    0x8F00,
    0xDF00,
  },
};


#undef  IMAGEWIDTH
#undef  IMAGEHEIGHT
#define IMAGEWIDTH       12
#define IMAGEHEIGHT      12

USHORT DLeftArrowData[IMAGEDEPTH][IMAGEHEIGHT*WORDSPERROW] =
{
  {
    0xFFF0,
    0x8410,
    0x8810,
    0x93D0,
    0xA030,
    0xC030,
    0xC030,
    0xA030,
    0x93F0,
    0x8810,
    0x8410,
    0xFFF0,
  },
  {
    0x0010,
    0x7FF0,
    0x7BF0,
    0x73F0,
    0x6010,
    0x4010,
    0x0010,
    0x4010,
    0x6010,
    0x73F0,
    0x7BF0,
    0xFFF0,
  },
};

#undef  WORDSPERROW

#define DAVEWIDTH       45
#define DAVEHEIGHT      47
#define DAVEDEPTH        2
#define WORDSPERROW      3

USHORT DaveData[DAVEDEPTH][DAVEHEIGHT*WORDSPERROW] =
{
  {
    0xFFFF, 0xFFFF, 0xFFF8,
    0x8000, 0x0000, 0x0008,
    0x8000, 0x0800, 0x0008,
    0x8001, 0xFFE0, 0x0008,
    0x800F, 0xFFF8, 0x0008,
    0x801F, 0xC03C, 0x0008,
    0x8078, 0x002E, 0x0008,
    0x80F0, 0x0007, 0x8008,
    0x80E0, 0x3D00, 0xC008,
    0x81C0, 0xFF80, 0x0008,
    0x8001, 0xFFF0, 0x3008,
    0x8001, 0xFFF0, 0x3808,
    0x8003, 0xFFF0, 0x1808,
    0x8407, 0xFFF0, 0x0C08,
    0x8C07, 0xFFF8, 0x0E08,
    0x9C03, 0xFFF8, 0x0E08,
    0x9E00, 0x03E7, 0xEE08,
    0x9F00, 0x03C0, 0x0E08,
    0x8F00, 0x43C0, 0x0F08,
    0x8F80, 0x03C3, 0x0F08,
    0x8F80, 0xC1C2, 0x0E08,
    0x8F80, 0x0180, 0x0E08,
    0x8D8C, 0x4480, 0x0408,
    0x8DC7, 0xFFC0, 0x0408,
    0x8407, 0xFFE1, 0x8008,
    0x8107, 0xF8F3, 0xC008,
    0x8187, 0xFBE1, 0xC008,
    0x8183, 0xFC60, 0xE008,
    0x8003, 0xFD00, 0x0008,
    0x8001, 0xFEC0, 0x0008,
    0x8001, 0xE2E0, 0x0008,
    0x8001, 0xCFE0, 0x0008,
    0x8000, 0x4000, 0x0008,
    0x8000, 0xF8E0, 0x0008,
    0x8000, 0x7FC0, 0x0008,
    0x8000, 0x3F80, 0x0008,
    0x8000, 0x0FC0, 0x0008,
    0x8000, 0x06F0, 0x0008,
    0x8000, 0x00F0, 0x0008,
    0x8000, 0x0000, 0x0008,
    0x8000, 0x0000, 0x0008,
    0x8000, 0x0000, 0x0008,
    0x8000, 0x0000, 0x0008,
    0x8000, 0x0380, 0x0008,
    0x8000, 0x0300, 0x0008,
    0x8000, 0x0000, 0x0708,
    0xFFFF, 0xFFFF, 0xFFF8,
  },
  {
    0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0008,
    0x0000, 0x0800, 0x0008,
    0x0001, 0xFFE0, 0x0008,
    0x000F, 0xFFF8, 0x0008,
    0x001F, 0xC03C, 0x0008,
    0x0078, 0x102E, 0x0008,
    0x00F1, 0xFF87, 0x8008,
    0x00E7, 0xC2F8, 0xC008,
    0x01CF, 0x007C, 0x0008,
    0x001E, 0x000E, 0x3008,
    0x003E, 0x000F, 0x3808,
    0x003C, 0x000F, 0x9808,
    0x0438, 0x000F, 0x8C08,
    0x0C18, 0x0007, 0x8E08,
    0x1C3C, 0x0006, 0x0E08,
    0x1E3F, 0x8C17, 0xEE08,
    0x1F38, 0x0023, 0xCE08,
    0x0F33, 0xBC3F, 0x6F08,
    0x0FB7, 0xFC3B, 0x0F08,
    0x0FBF, 0xCE1E, 0x8E08,
    0x0FBC, 0x1E6F, 0x1E08,
    0x0DB3, 0xBB7F, 0xF408,
    0x0DF8, 0x003F, 0xF408,
    0x0718, 0x001E, 0x7808,
    0x0298, 0x0704, 0x3808,
    0x0058, 0x041E, 0x3008,
    0x004C, 0x0297, 0x1008,
    0x00CC, 0x02FF, 0xF008,
    0x00EE, 0x013F, 0xF008,
    0x0026, 0x1D1F, 0xF008,
    0x0006, 0x301E, 0xF008,
    0x0007, 0xB3F9, 0xE008,
    0x0003, 0x071F, 0xE008,
    0x0003, 0x803F, 0xC008,
    0x0001, 0xC07F, 0x8008,
    0x0000, 0xF03F, 0x0008,
    0x0004, 0xF90E, 0x0008,
    0x0006, 0x7F0C, 0x0008,
    0x0007, 0x0FFC, 0x0008,
    0x0007, 0x8100, 0x0008,
    0x0007, 0xE000, 0x0008,
    0x0007, 0xFFC1, 0xC008,
    0x0007, 0xFC7B, 0xC008,
    0x0007, 0xFCFF, 0xC008,
    0x0007, 0xFFFF, 0xE708,
    0x7FFF, 0xFFFF, 0xFFF8,
  },
};
